@@ -20,7 +20,7 @@ License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 """
 
-__version__ = "0.4"
+__version__ = "0.4.1"
 
 from libxml2dom.macrolib import *
 from libxml2dom.macrolib import \
@@ -325,6 +325,9 @@ class Node(object):
     def createComment(self, value):
         return self.impl.get_node(Node_createComment(self._node, value), self)
 
+    def createCDATASection(self, value):
+        return self.impl.get_node(Node_createCDATASection(self._node, value), self)
+
     def importNode(self, node, deep):
         if hasattr(node, "as_native_node"):
             return self.impl.get_node(Node_importNode(self._node, node.as_native_node(), deep), self)
