@@ -411,6 +411,11 @@ def Node_createComment(node, value):
 
     return libxml2mod.xmlNewComment(value)
 
+def Node_createCDATASection(node, value):
+    value = from_unicode(value)
+
+    return libxml2mod.xmlNewCDataBlock(Node_ownerDocument(node), value, len(value))
+
 def Node_insertBefore(node, tmp, oldNode):
     check_document(node, tmp)
     return libxml2mod.xmlAddPrevSibling(oldNode, tmp)
@@ -446,6 +451,9 @@ def Node_importNode(node, other, deep):
     elif Node_nodeType(other) == xml.dom.Node.COMMENT_NODE:
         return Node_createComment(node, Node_data(other))
 
+    elif Node_nodeType(other) == xml.dom.Node.CDATA_SECTION_NODE:
+        return Node_createCDATASection(node, Node_data(other))
+
     raise xml.dom.DOMException(xml.dom.NOT_SUPPORTED_ERR, "Node type '%s' (%d) not supported." % (other, Node_nodeType(other)))
 
 def Node_importNode_DOM(node, other, deep):
@@ -468,6 +476,9 @@ def Node_importNode_DOM(node, other, deep):
     elif other.nodeType == xml.dom.Node.COMMENT_NODE:
         return Node_createComment(node, other.data)
 
+    elif other.nodeType == xml.dom.Node.CDATA_SECTION_NODE:
+        return Node_createCDATASection(node, other.data)
+
     raise xml.dom.DOMException(xml.dom.NOT_SUPPORTED_ERR, "Node type '%s' (%d) not supported." % (_reverseNodeTypes[other.nodeType], other.nodeType))
 
 def Node_xpath(node, expr, variables=None, namespaces=None):
